==> estateplat-common-1.2.3-20180529.081144-100-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfMmhtGhsjbg.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;


/*
 * @author <a href="mailto:lizhi@gtmap.cn">lizhi</a>
 * @version 1.0, 2017/12/6
 * @description    规划设计变更表
 */
@Table(name = "fcjy_xjspf_mmht_ghsjbg")
public class FcjyXjspfMmhtGhsjbg {
    @Id
    private String bgid;//主键
    private String htid;//合同ID
    private Integer ghbgjflx;//规划变更给付利息
    private Double ghbgwyj;//规划变更违约金
    private String ghbgsfyd;//规划变更双方约定
    private String bgtm3;//变更条目3
    private String bgtm4;//变更条目4
    private String bgtm5;//变更条目5
    private String sjbgjflx;//设计变更给付利息
    private Double sjbgwyj;//设计变更违约金
    private String sjbgsfyd;//设计变更双方约定

    public String getBgid() {
        return bgid;
    }

    public void setBgid(String bgid) {
        this.bgid = bgid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public Integer getGhbgjflx() {
        return ghbgjflx;
    }

    public void setGhbgjflx(Integer ghbgjflx) {
        this.ghbgjflx = ghbgjflx;
    }

    public Double getGhbgwyj() {
        return ghbgwyj;
    }

    public void setGhbgwyj(Double ghbgwyj) {
        this.ghbgwyj = ghbgwyj;
    }

    public String getGhbgsfyd() {
        return ghbgsfyd;
    }

    public void setGhbgsfyd(String ghbgsfyd) {
        this.ghbgsfyd = ghbgsfyd;
    }

    public String getBgtm3() {
        return bgtm3;
    }

    public void setBgtm3(String bgtm3) {
        this.bgtm3 = bgtm3;
    }

    public String getBgtm4() {
        return bgtm4;
    }

    public void setBgtm4(String bgtm4) {
        this.bgtm4 = bgtm4;
    }

    public String getBgtm5() {
        return bgtm5;
    }

    public void setBgtm5(String bgtm5) {
        this.bgtm5 = bgtm5;
    }

    public String getSjbgjflx() {
        return sjbgjflx;
    }

    public void setSjbgjflx(String sjbgjflx) {
        this.sjbgjflx = sjbgjflx;
    }

    public Double getSjbgwyj() {
        return sjbgwyj;
    }

    public void setSjbgwyj(Double sjbgwyj) {
        this.sjbgwyj = sjbgwyj;
    }

    public String getSjbgsfyd() {
        return sjbgsfyd;
    }

    public void setSjbgsfyd(String sjbgsfyd) {
        this.sjbgsfyd = sjbgsfyd;
    }
}

==> estateplat-common-1.2.3-20180603.082812-106-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfMmhtGhsjbg.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;


/*
 * @author <a href="mailto:lizhi@gtmap.cn">lizhi</a>
 * @version 1.0, 2017/12/6
 * @description    规划设计变更表
 */
@Table(name = "fcjy_xjspf_mmht_ghsjbg")
public class FcjyXjspfMmhtGhsjbg implements Serializable {
    @Id
    private String bgid;//主键
    private String htid;//合同ID
    private Integer ghbgjflx;//规划变更给付利息
    private Double ghbgwyj;//规划变更违约金
    private String ghbgsfyd;//规划变更双方约定
    private String bgtm3;//变更条目3
    private String bgtm4;//变更条目4
    private String bgtm5;//变更条目5
    private String sjbgjflx;//设计变更给付利息
    private Double sjbgwyj;//设计变更违约金
    private String sjbgsfyd;//设计变更双方约定

    public String getBgid() {
        return bgid;
    }

    public void setBgid(String bgid) {
        this.bgid = bgid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public Integer getGhbgjflx() {
        return ghbgjflx;
    }

    public void setGhbgjflx(Integer ghbgjflx) {
        this.ghbgjflx = ghbgjflx;
    }

    public Double getGhbgwyj() {
        return ghbgwyj;
    }

    public void setGhbgwyj(Double ghbgwyj) {
        this.ghbgwyj = ghbgwyj;
    }

    public String getGhbgsfyd() {
        return ghbgsfyd;
    }

    public void setGhbgsfyd(String ghbgsfyd) {
        this.ghbgsfyd = ghbgsfyd;
    }

    public String getBgtm3() {
        return bgtm3;
    }

    public void setBgtm3(String bgtm3) {
        this.bgtm3 = bgtm3;
    }

    public String getBgtm4() {
        return bgtm4;
    }

    public void setBgtm4(String bgtm4) {
        this.bgtm4 = bgtm4;
    }

    public String getBgtm5() {
        return bgtm5;
    }

    public void setBgtm5(String bgtm5) {
        this.bgtm5 = bgtm5;
    }

    public String getSjbgjflx() {
        return sjbgjflx;
    }

    public void setSjbgjflx(String sjbgjflx) {
        this.sjbgjflx = sjbgjflx;
    }

    public Double getSjbgwyj() {
        return sjbgwyj;
    }

    public void setSjbgwyj(Double sjbgwyj) {
        this.sjbgwyj = sjbgwyj;
    }

    public String getSjbgsfyd() {
        return sjbgsfyd;
    }

    public void setSjbgsfyd(String sjbgsfyd) {
        this.sjbgsfyd = sjbgsfyd;
    }
}
